// @flow

const meta = {
  docs: {
    description:
      'Use the autogenerated hooks in api.ts instead of manually writing useQuery hooks in other files',
  },
};

const create = (context) => {
  const fileName = context.getFilename().split('/').pop();

  // Check if the file name includes "api"
  if (fileName.includes('api')) {
    return {};
  }
  return {
    ImportDeclaration(node) {
      if (node.source.value === 'react-query') {
        node.specifiers.forEach((specifier) => {
          // if useQuery, useQueries, or useMutation
          if (
            specifier.local.name === 'useQuery' ||
            specifier.local.name === 'useQueries' ||
            specifier.local.name === 'useMutation'
          ) {
            context.report({
              message: `Use the autogenerated hooks in api.ts instead of manually writing useQuery hooks in other files`,
              node,
            });
          }
        });
      }
      if (node.source.value.includes('generated.ts')) {
        context.report({
          message: `generated.ts has been deprecated. Use the autogenerated hooks in api.ts instead`,
          node,
        });
      }
    },
  };
};

module.exports = { create, meta };
